OC.L10N.register(
    "spreed",
    {
    "Validate SSL certificate" : "Validera SSL-certifikat",
    "Delete server" : "Ta bort server",
    "Add new server" : "Lägg till ny server",
    "Saved" : "Sparad",
    "You deleted all STUN servers. As it is almost always needed, a default STUN server was added." : "Du raderade alla STUN-servrar. Eftersom det nästan alltid behövs har en standard STUN-server lagts till.",
    "Shared secret" : "Delad hemlighet",
    "TURN server shared secret" : "TURN server delade hemlighet",
    "UDP and TCP" : "UDP och TCP",
    "UDP only" : "endast UDP",
    "TCP only" : "endast TCP",
    "TURN server protocols" : "TURN server protokoll",
    "New public conversation" : "Ny publik konversation",
    "New group conversation" : "Ny gruppkonversation",
    "{name} (public)" : "{name} (publik)",
    "New conversation …" : "Ny konversation",
    "Participants" : "Deltagare",
    "Chat" : "Chat",
    "Talk" : "Talk",
    "Exit fullscreen (f)" : "Avsluta fullskärmsläge (f)",
    "Fullscreen (f)" : "Fullskärm (f)",
    "Set your name in the chat window so other participants can identify you better." : "Ange ditt namn i chattfönstret så andra deltagare kan identifiera dig bättre. ",
    "Copy" : "Kopiera",
    "Copied!" : "Kopierat!",
    "Not supported!" : "Ej kompatibel!",
    "Press ⌘-C to copy." : "Tryck ⌘-C för att kopiera.",
    "Press Ctrl-C to copy." : "Tryck Ctrl-C för att kopiera.",
    "Error while getting the room ID" : "Fel vid mottagande av rum-ID",
    "Start a conversation" : "Starta en konversation",
    "Share this file with others to discuss" : "Dela den här filen med andra att diskutera",
    "Share" : "Dela",
    "Request password" : "Begär lösenord",
    "Error requesting the password." : "Fel vid begäran av lösenord.",
    "Please enter the password for this call" : "Var god ange lösenordet för detta samtal",
    "Password required" : "Lösenord krävs",
    "Password" : "Lösenord",
    "Cancel" : "Avbryt",
    "Submit" : "Skicka",
    "Leave call" : "Lämna samtalet",
    "Join call" : "Gå med i samtal",
    "Start call" : "Starta samtal",
    "Share link" : "Dela länk",
    "Change password" : "Byt lösenord",
    "Set password" : "Sätt lösenord",
    "Go to file" : "Gå till fil",
    "Name" : "Namn",
    "Conversation name" : "Konversationens namn",
    "Rename" : "Byt namn",
    "Copy link" : "Kopiera länk",
    "Conversation with {name}" : "Konversation med {name}",
    "Error occurred while setting password" : "Fel inträffade när lösenord sattes",
    "Link copied!" : "Länk kopierad!",
    "You" : "Du",
    "No messages yet, start the conversation!" : "Inga meddelanden än, starta konversationen!",
    "New message …" : "Nytt meddelande",
    "Send" : "Skicka",
    "Guest" : "Gäst",
    "[Unknown user name]" : "[Okänt användarnam]",
    "Today" : "Idag",
    "Yesterday" : "Igår",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "The message you are trying to send is too long" : "Meddelandet du försöker skicka är för långt",
    "Error occurred while sending message" : "Fel inträffade när meddelande sändes",
    "File to share" : "Fil att dela",
    "Error while sharing" : "Fel vid delning",
    "Edit" : "Ändra",
    "Join a conversation or start a new one" : "Anslut till en konversation eller starta en ny",
    "Say hi to your friends and colleagues!" : "Säg hej till dina vänner och kollegor!",
    "No other people in this call" : "Inga andra personer i detta samtal",
    "Waiting for {participantName} to join the call …" : "Väntar på att {participantName} ansluter sig till samtalet ...",
    "Waiting for others to join the call …" : "Väntar på andra ansluter sig till samtalet ...",
    "You can invite others in the participant tab of the sidebar" : "Du kan bjuda in andra på fliken deltagare i sidofältet",
    "Share this link to invite others!" : "Dela denna länk för att bjuda in andra!",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Du kan bjuda in andra på fliken deltagare i sidofältet eller dela den här länken!",
    "WebRTC is not supported in your browser :-/" : "WebRTC är inte kompatibelt med din webbläsare :-/",
    "Please use a different browser like Firefox or Chrome" : "Vänligen använd en annan webbläsare som t.ex Firefox eller Chrome",
    "Waiting for camera and microphone permissions" : "Väntar på godkännande att använda kamera och mikrofon",
    "Please, give your browser access to use your camera and microphone in order to use this app." : "Vänligen ge din webbläsare tillåtelse att använda din kamera och mikrofon för att kunna använda denna funktion.",
    "This conversation has ended" : "Denna konversation har avslutats",
    "Mute audio" : "Stäng av ljudet",
    "Disable video" : "Stäng av video",
    "Share screen" : "Dela skärm",
    "Share whole screen" : "Dela hela skärmen",
    "Share a single window" : "Dela ett fönster",
    "Show your screen" : "Visa din skärm",
    "Stop screensharing" : "Stoppa skärmdelning",
    "Unmute audio (m)" : "Ljud på (m)",
    "Mute audio (m)" : "Ljud av (m)",
    "No audio" : "Inget ljud",
    "Enable video (v)" : "Aktivera video (v)",
    "Disable video (v)" : "Inaktivera video (v)",
    "No Camera" : "Ingen kamera",
    "Screensharing is not supported by your browser." : "Skärmdelning fungerar inte i din nuvarande webbläsare.",
    "Screensharing requires the page to be loaded through HTTPS." : "Skärmdelning kräver HTTPS",
    "Screensharing options" : "Skärmdelningsalternativ",
    "Sharing your screen only works with Firefox version 52 or newer." : "Skärmdelning fungerar endast med Firefox version 52 eller nyare.",
    "Screensharing extension is required to share your screen." : "Skärmdelningstillägg krävs för att dela din skärm.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Vänligen använd en annan webbläsare som t.ex Firefox eller Chrome för att dela din skärm.",
    "An error occurred while starting screensharing." : "Ett fel uppstod vid skärmdelning.",
    "Enable screensharing" : "Tillåt skärmdelning",
    "moderator" : "moderator",
    "Demote from moderator" : "Degradera från moderator",
    "Promote to moderator" : "Befordra till moderator",
    "Remove participant" : "Ta bort deltagare",
    "Error while promoting user to moderator" : "Kunde inte göra användaren till moderator",
    "Error while demoting moderator" : "Kunde inte ta bort moderator",
    "Error while removing user from room" : "Kunde inte ta bort användaren från rummet",
    "Add participant …" : "Lägg till deltagare",
    "Favorited" : "Favorit",
    "Remove from favorites" : "Ta bort från favoriter",
    "Add to favorites" : "Lägg till som favorit",
    "Always notify" : "Meddela alltid",
    "Notify on @-mention" : "Meddela på @-mention",
    "Never notify" : "Meddela aldrig",
    "Leave conversation" : "Lämna konversationen",
    "Delete conversation" : "Radera konversationen",
    "Close" : "Stäng",
    "Show screen" : "Visa skärm",
    "Enable video" : "Aktivera video",
    "Access to microphone & camera is only possible with HTTPS" : "Tillgång till mikrofon och kamera är endast möjligt via HTTPS",
    "Please move your setup to HTTPS" : "Vänligen flytta din inställning till HTTPS",
    "Access to microphone & camera was denied" : "Tillgång till mikrofon och kamera blev nekad",
    "WebRTC is not supported in your browser" : "WebRTC är inte kompatibelt med din webbläsare",
    "Error while accessing microphone & camera" : "Kunde ej ansluta mikrofon och kamera",
    "{participantName}'s screen" : "{participantName}'s skärm",
    "Guest's screen" : "Gästskärm",
    "Your screen" : "Din skärm",
    "a conversation" : "en konversation",
    "(Duration %s)" : "(Varaktighet%s)",
    "You attended a call with {user1}" : "Du deltog i ett samtal med {user1}",
    "_%n guest_::_%n guests_" : ["%n gäst","%n gäster"],
    "You attended a call with {user1} and {user2}" : "Du deltog i ett samtal med {user1} och {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Du deltog i ett samtal med {user1}, {user2} och {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Du deltog i ett samtal med {user1}, {user2}, {user3} och {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Du deltog i ett samtal med {user1}, {user2}, {user3}, {user4} och {user5}",
    "_%n other_::_%n others_" : ["%n annan","%n andra"],
    "{actor} invited you to {call}" : "{actor} bjöd in dig till {call}",
    "You were invited to a <strong>talk</strong> room or had a <strong>call</strong>" : "Du bjöds in för ett <strong>pratrum</strong> eller hade ett <strong>samtal</strong>",
    "{actor} created the conversation" : "{actor} skapade konversationen",
    "You created the conversation" : "Du skapade konversationen",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} bytte namn på konversationen från \"%1$s\" till \"%2$s\"",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Du bytte namn på konversationen från \"%1$s\" till \"%2$s\"",
    "{actor} started a call" : "{actor} startade ett samtal",
    "You started a call" : "Du startade ett samtal",
    "{actor} joined the call" : "{actor} gick med i samtalet",
    "You joined the call" : "Du gick med i samtalet",
    "{actor} left the call" : "{actor} lämnade samtalet",
    "You left the call" : "Du lämnade samtalet",
    "{actor} allowed guests" : "{actor} tillåter gäster",
    "You allowed guests" : "Du tillåter gäster",
    "{actor} disallowed guests" : "{actor} tillåter inte gäster",
    "You disallowed guests" : "Du tillåter inte gäster",
    "{actor} set a password" : "{actor} satte ett lösenord",
    "You set a password" : "Du satte ett lösenord",
    "{actor} removed the password" : "{actor} tog bort lösenordet",
    "You removed the password" : "Du tog bort lösenordet",
    "{actor} added {user}" : "{actor} la till {user}",
    "You joined the conversation" : "Du gick med i konversationen",
    "{actor} joined the conversation" : "{actor} gick med i konversationen",
    "You added {user}" : "Du la till {user}",
    "{actor} added you" : "{actor} la till dig",
    "You left the conversation" : "Du lämnade konversationen",
    "{actor} left the conversation" : "{actor} lämnade konversationen",
    "{actor} removed {user}" : "{actor} tog bort {user}",
    "You removed {user}" : "Du tog bort {user}",
    "{actor} removed you" : "{actor} tog bort dig",
    "{actor} promoted {user} to moderator" : "{actor} gjorde {user} till moderator",
    "You promoted {user} to moderator" : "Du gjorde {user} till moderator",
    "{actor} promoted you to moderator" : "{actor} gjorde dig moderator",
    "{actor} demoted {user} from moderator" : "{actor} tog bort {user} som moderator",
    "You demoted {user} from moderator" : "Du tog bort {user} som moderator",
    "{actor} demoted you from moderator" : "{actor} tog bort dig som moderator",
    "{actor} shared a file which is no longer available" : "{actor} delade en fil som inte längre är tillgänglig",
    "You shared a file which is no longer available" : "Du delade en fil som inte längre är tillgänglig",
    "%s (guest)" : "%s (gäst)",
    "Call with {user1} and {user2} (Duration {duration})" : "Samtal med {user1} och {user2} (Varade {duration})",
    "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Samtal med {user1}, {user2} och {user3} (Varade {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Samtal med {user1}, {user2}, {user3} och {user4} (Varade {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Samtal med {user1}, {user2}, {user3}, {user4} och {user5} (Varade {duration})",
    "Talk to %s" : "Prata med %s",
    "File is not shared, or shared but not with the user" : "Filen delas inte eller delas men inte med användaren",
    "Password request: %s" : "Lösenordsförfrågan: %s",
    "_%n other guest_::_%n other guests_" : ["%n annan gäst","%n andra gäster"],
    ", " : ",",
    "%s invited you to a conversation." : "%s bjöd in dig till en konversation.",
    "You were invited to a conversation." : "Du blev inbjuden till en konversation.",
    "Conversation invitation" : "Inbjudan till konversation",
    "Click the button below to join." : "Klicka på knappen nedan för att gå med.",
    "Join »%s«" : "Anslut »%s«",
    "Join now" : "Anslut nu",
    "{user} sent you a private message" : "{user} skickade dig ett privat meddelande",
    "{user} sent a message in conversation {call}" : "{user} skickade ett meddelande i konversation {call}",
    "{user} sent a message in a conversation" : "{user} skickade ett meddelande i en konversation",
    "A deleted user sent a message in conversation {call}" : "En raderad användare skickade ett meddelande i konversation {call}",
    "A deleted user sent a message in a conversation" : "En raderad användare skickade ett meddelande i en konversation",
    "A guest sent a message in conversation {call}" : "En gäst skickade ett meddelande i konversation {call}",
    "A guest sent a message in a conversation" : "En gäst skickade ett meddelande i en konversation",
    "{user} mentioned you in a private conversation" : "{user} nämnde dig i en privat konversation",
    "{user} mentioned you in conversation {call}" : "{user} nämnde dig i konversation {call}",
    "{user} mentioned you in a conversation" : "{user} nämnde dig i en konversation",
    "A deleted user mentioned you in conversation {call}" : "En raderad användare nämnde dig i konversation {call}",
    "A deleted user mentioned you in a conversation" : "En raderad användare nämnde dig i en konversation",
    "A guest mentioned you in conversation {call}" : "En gäst nämnde dig i konversation {call}",
    "A guest mentioned you in a conversation" : "En gäst nämnde dig i en konversation",
    "%s invited you to a private conversation" : "%s bjöd in dig till en privat konversation",
    "{user} invited you to a private conversation" : "{user} bjöd in dig till en privat konversation",
    "%s invited you to a group conversation: %s" : "%s bjöd in dig till en gruppkonversation: %s",
    "{user} invited you to a group conversation: {call}" : "{user} bjöd in dig till en gruppkonversation: {call}",
    "%s invited you to a group conversation" : "%s bjöd in dig till en gruppkonversation",
    "{user} invited you to a group conversation" : "{user} bjöd in dig till en gruppkonversation",
    "{user} wants to talk with you" : "{user} vill prata med dig",
    "A group call has started in {call}" : "Ett gruppsamtal har startats i {call}",
    "A group call has started" : "Ett gruppsamtal har startats",
    "{email} requested the password to access {file}" : "{email} begärde lösenordet för åtkomst till {file}",
    "Someone requested the password to access {file}" : "Någon begärde lösenordet för att komma åt {file}",
    "Invalid date, date format must be YYYY-MM-DD" : "Felaktigt datum, datumformat måste vara ÅÅÅÅ-MM-DD",
    "Conversation not found" : "Konversationen hittades inte",
    "Path is already shared with this room" : "Sökvägen är redan delad med detta rum",
    "Video & audio-conferencing using WebRTC" : "Video- och ljudkonferens med WebRTC",
    "This call is password-protected" : "Detta samtal är lösenordsskyddat",
    "The password is wrong. Try again." : "Lösenordet är fel. Försök igen.",
    "Signaling server" : "Signalerar server",
    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "En extern signalserver kan eventuellt användas för större installationer. Lämna tomt för att använda den interna signalservern.",
    "STUN servers" : "STUN-servrar",
    "A STUN server is used to determine the public IP address of participants behind a router." : "En STUN-server används för att bestämma den offentliga IP-adressen av deltagare bakom en router.",
    "TURN server" : "TURN server",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN-servern används för att tunnla trafiken för användare som sitter bakom en brandvägg.",
    "%s Talk on your mobile devices" : "%s Talk på dina mobila enheter",
    "Join conversations at any time, any where, on any device." : "Anslut dig till konversationer när som helst, var som helst och på valfri enhet.",
    "Android app" : "Android-app",
    "iOS app" : " iOS-app",
    "(group)" : " (grupp)",
    "and you" : "och du",
    "… %s" : "… %s",
    "%s …" : "%s …",
    "… %s …" : "… %s …",
    "%s mentioned you in a private conversation" : "%s nämnde dig i en privat konversation",
    "%s mentioned you in a group conversation: %s" : "%s nämnde dig i en gruppkonversation: %s",
    "{user} mentioned you in a group conversation: {call}" : "{user} nämnde dig i en gruppkonversation: {call}",
    "%s mentioned you in a group conversation" : "%s nämnde dig i en gruppkonversation",
    "{user} mentioned you in a group conversation" : "{user} nämnde dig i en gruppkonversation",
    "You were mentioned in a group conversation by a deleted user: %s" : "Du nämndes i en gruppkonversation av en raderad användare: %s",
    "You were mentioned in a group conversation by a deleted user: {call}" : "Du nämndes i en gruppkonversation av en raderad användare: {call}",
    "You were mentioned in a group conversation by a deleted user" : "Du nämndes i en gruppkonversation av en raderad användare",
    "A guest mentioned you in a group conversation: %s" : "En gäst nämnde dig i en gruppkonversation: %s",
    "A guest mentioned you in a group conversation: {call}" : "En gäst nämnde dig i en gruppkonversation: {call}",
    "A guest mentioned you in a group conversation" : "En gäst nämnde dig i en gruppkonversation",
    "Password request by %s" : "Lösenordet efterfrågas av %s",
    "{email} requested the password to access a share" : "{email} begärde lösenordet för att komma åt en delning"
},
"nplurals=2; plural=(n != 1);");
